@@ -1,17 +1,7 @@
 //! Contains a borrowed Object bound to a buffer holding its decompressed data.
 
-use git_object::immutable;
-
-/// A borrowed object using a borrowed slice as backing buffer.
-#[derive(PartialEq, Eq, Debug, Hash, Ord, PartialOrd, Clone)]
-pub struct Object<'a> {
-    /// kind of object
-    pub kind: git_object::Kind,
-    /// decoded, decompressed data, owned by a backing store.
-    pub data: &'a [u8],
-    /// If `Some`, this object is from a pack whose pack location can be used to look up pack related information
-    pub pack_location: Option<crate::bundle::Location>,
-}
+use crate::data::Object;
+use git_object::{BlobRef, CommitRef, CommitRefIter, ObjectRef, TagRef, TagRefIter, TreeRef, TreeRefIter};
 
 impl<'a> Object<'a> {
     /// Constructs a new data object from `kind` and `data`.
@@ -22,43 +12,43 @@ impl<'a> Object<'a> {
             pack_location: None,
         }
     }
-    /// Decodes the data in the backing slice into a [`git_object::immutable::Object`], allowing to access all of its data
+    /// Decodes the data in the backing slice into a [`git_object::ObjectRef`], allowing to access all of its data
     /// conveniently. The cost of parsing an object is negligible.
     ///
-    /// **Note** that [mutable, decoded objects][git_object::mutable::Object] can be created from a [`crate::data::Object`]
-    /// using [`git_object::immutable::Object::into_mutable()`].
-    pub fn decode(&self) -> Result<immutable::Object<'a>, immutable::object::decode::Error> {
+    /// **Note** that [mutable, decoded objects][git_object::Object] can be created from a [`crate::data::Object`]
+    /// using [`git_object::ObjectRef::into_owned()`].
+    pub fn decode(&self) -> Result<ObjectRef<'a>, git_object::decode::Error> {
         Ok(match self.kind {
-            git_object::Kind::Tree => immutable::Object::Tree(immutable::Tree::from_bytes(self.data)?),
-            git_object::Kind::Blob => immutable::Object::Blob(immutable::Blob { data: self.data }),
-            git_object::Kind::Commit => immutable::Object::Commit(immutable::Commit::from_bytes(self.data)?),
-            git_object::Kind::Tag => immutable::Object::Tag(immutable::Tag::from_bytes(self.data)?),
+            git_object::Kind::Tree => ObjectRef::Tree(TreeRef::from_bytes(self.data)?),
+            git_object::Kind::Blob => ObjectRef::Blob(BlobRef { data: self.data }),
+            git_object::Kind::Commit => ObjectRef::Commit(CommitRef::from_bytes(self.data)?),
+            git_object::Kind::Tag => ObjectRef::Tag(TagRef::from_bytes(self.data)?),
         })
     }
 
     /// Returns this object as tree iterator to parse entries one at a time to avoid allocations, or
     /// `None` if this is not a tree object.
-    pub fn into_tree_iter(self) -> Option<immutable::TreeIter<'a>> {
+    pub fn into_tree_iter(self) -> Option<TreeRefIter<'a>> {
         match self.kind {
-            git_object::Kind::Tree => Some(immutable::TreeIter::from_bytes(self.data)),
+            git_object::Kind::Tree => Some(TreeRefIter::from_bytes(self.data)),
             _ => None,
         }
     }
 
     /// Returns this object as commit iterator to parse tokens one at a time to avoid allocations, or
     /// `None` if this is not a commit object.
-    pub fn into_commit_iter(self) -> Option<immutable::CommitIter<'a>> {
+    pub fn into_commit_iter(self) -> Option<CommitRefIter<'a>> {
         match self.kind {
-            git_object::Kind::Commit => Some(immutable::CommitIter::from_bytes(self.data)),
+            git_object::Kind::Commit => Some(CommitRefIter::from_bytes(self.data)),
             _ => None,
         }
     }
 
     /// Returns this object as tag iterator to parse tokens one at a time to avoid allocations, or
     /// `None` if this is not a tag object.
-    pub fn into_tag_iter(self) -> Option<immutable::TagIter<'a>> {
+    pub fn into_tag_iter(self) -> Option<TagRefIter<'a>> {
         match self.kind {
-            git_object::Kind::Tag => Some(immutable::TagIter::from_bytes(self.data)),
+            git_object::Kind::Tag => Some(TagRefIter::from_bytes(self.data)),
             _ => None,
         }
     }
