@@ -57,20 +57,68 @@ where
         matches!(version, crate::data::Version::V2),
         "currently we can only write version 2"
     );
+    let (chunk_size, thread_limit, _) =
+        parallel::optimize_chunk_size_and_thread_limit(chunk_size, Some(counts.len()), thread_limit, None);
+    let chunks = util::ChunkRanges::new(chunk_size, counts.len());
+    {
+        let progress = Arc::new(parking_lot::Mutex::new(progress.add_child("resolving")));
+        progress
+            .lock()
+            .init(Some(counts.len()), git_features::progress::count("counts"));
+        let enough_counts_present = counts.len() > 4_000;
+        let start = std::time::Instant::now();
+        parallel::in_parallel_if(
+            || enough_counts_present,
+            chunks.clone(),
+            thread_limit,
+            |_n| Vec::<u8>::new(),
+            {
+                let progress = Arc::clone(&progress);
+                let counts = &counts;
+                let db = &db;
+                move |chunk_range, buf| {
+                    let chunk = {
+                        let c = &counts[chunk_range];
+                        let mut_ptr = c.as_ptr() as *mut output::Count;
+                        // SAFETY: We know that 'chunks' is only non-overlapping slices, and this function owns `counts`.
+                        #[allow(unsafe_code)]
+                        unsafe {
+                            std::slice::from_raw_parts_mut(mut_ptr, c.len())
+                        }
+                    };
+                    let chunk_size = chunk.len();
+                    for count in chunk {
+                        use crate::data::output::count::PackLocation::*;
+                        match count.entry_pack_location {
+                            LookedUp(_) => continue,
+                            NotLookedUp => count.entry_pack_location = LookedUp(db.location_by_oid(count.id, buf)),
+                        }
+                    }
+                    progress.lock().inc_by(chunk_size);
+                    Ok::<_, ()>(())
+                }
+            },
+            parallel::reduce::IdentityWithResult::<(), ()>::default(),
+        )
+        .expect("infallible - we ignore none-existing objects");
+        progress.lock().show_throughput(start);
+    }
     let counts_range_by_pack_id = match mode {
         Mode::PackCopyAndBaseObjects => {
             let mut progress = progress.add_child("sorting");
             progress.init(Some(counts.len()), git_features::progress::count("counts"));
             let start = std::time::Instant::now();
 
+            use crate::data::output::count::PackLocation::*;
             counts.sort_by(|lhs, rhs| match (&lhs.entry_pack_location, &rhs.entry_pack_location) {
-                (None, None) => Ordering::Equal,
-                (Some(_), None) => Ordering::Greater,
-                (None, Some(_)) => Ordering::Less,
-                (Some(lhs), Some(rhs)) => lhs
+                (LookedUp(None), LookedUp(None)) => Ordering::Equal,
+                (LookedUp(Some(_)), LookedUp(None)) => Ordering::Greater,
+                (LookedUp(None), LookedUp(Some(_))) => Ordering::Less,
+                (LookedUp(Some(lhs)), LookedUp(Some(rhs))) => lhs
                     .pack_id
                     .cmp(&rhs.pack_id)
                     .then(lhs.pack_offset.cmp(&rhs.pack_offset)),
+                (_, _) => unreachable!("counts were resolved beforehand"),
             });
 
             let mut index: Vec<(u32, std::ops::Range<usize>)> = Vec::new();
@@ -93,13 +141,10 @@ where
         }
     };
     let counts = Arc::new(counts);
-    let (chunk_size, thread_limit, _) =
-        parallel::optimize_chunk_size_and_thread_limit(chunk_size, Some(counts.len()), thread_limit, None);
-    let chunks = util::ChunkRanges::new(chunk_size, counts.len()).enumerate();
     let progress = Arc::new(parking_lot::Mutex::new(progress));
 
     parallel::reduce::Stepwise::new(
-        chunks,
+        chunks.enumerate(),
         thread_limit,
         {
             let progress = Arc::clone(&progress);
@@ -172,7 +217,7 @@ where
                                     stats.objects_copied_from_pack += 1;
                                     entry
                                 }
-                                None => match db.find(count.id, buf, cache).map_err(Error::FindExisting)? {
+                                None => match db.try_find(count.id, buf, cache).map_err(Error::FindExisting)? {
                                     Some(obj) => {
                                         stats.decoded_and_recompressed_objects += 1;
                                         output::Entry::from_data(count, &obj)
@@ -184,7 +229,7 @@ where
                                 },
                             }
                         }
-                        None => match db.find(count.id, buf, cache).map_err(Error::FindExisting)? {
+                        None => match db.try_find(count.id, buf, cache).map_err(Error::FindExisting)? {
                             Some(obj) => {
                                 stats.decoded_and_recompressed_objects += 1;
                                 output::Entry::from_data(count, &obj)
@@ -205,6 +250,7 @@ where
 }
 
 mod util {
+    #[derive(Clone)]
     pub struct ChunkRanges {
         cursor: usize,
         size: usize,
